Determine the indexes of the non-overlapping clusters
Usage
noc(x)
Arguments
x
A list containing the indexes of the potential clusters.
Value
A vector with the list indexes of the non-overlapping clusters.
Details
The functions takes a list of potential cluster indexes. Each element of the list contains a potential cluster. The potential clusters are defined by the location indexes of the regions comprising the clusters. Starting with the first potential cluster, the function excludes every potential cluster that intersects the first (look at the location indexes comprising each cluster). Moving onto the next non-overlapping cluster, the process is repeated. The function returns the indexes (in the list of clusters) that do not overlap.